==> vmp-0.6.1.tar.xz: vmp-0.6.1/framework/python/vmp_json/__init__.py <==
#!/usr/bin/python

#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License version 3 as
#published by the Free Software Foundation;

#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.

#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#Author: Marco Guastella alias Vasta
#Web page:<www.ragnu.it>
#Email: <vasta@ragnu.it>
#Date last Update : 01/03/2024

from vmp_json_  import Json    as Json
from vmp_json_  import JsonObj as JsonObj
from vmp_json_  import JData   as JData
from vmp_json_  import JList   as JList
from vmp_json_  import JTable  as JTable

from vmp_json_  import japi               as japi
from vmp_json_  import japi_type_list     as japi_type_list
from vmp_json_  import japi_type_table    as japi_type_table
from vmp_json_  import japi_void          as japi_void
from vmp_json_  import japi_list          as japi_list
from vmp_json_  import japi_table         as japi_table
from vmp_json_  import japi_oper          as japi_oper
from vmp_json_  import japi_oper_kill     as japi_oper_kill
from vmp_json_  import japi_oper_data     as japi_oper_data
from vmp_json_  import japi_oper_data     as japi_oper_push
from vmp_json_  import japi_oper_close    as japi_oper_close
from vmp_json_  import japi_status        as japi_status
from vmp_json_  import japi_status_update as japi_status_update
from vmp_json_  import japi_status_cancel as japi_status_cancel

from vmp_json_  import status_input    as status_input
from vmp_json_  import status_response as status_response
from vmp_json_  import Status         as Status

from vmp_json_  import jrp  as jrp

==> vmp-0.7.1.tar.xz: vmp-0.7.1/framework/python/vmp_json/__init__.py <==
#!/usr/bin/python

#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License version 3 as
#published by the Free Software Foundation;

#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.

#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#Author: Marco Guastella alias Vasta
#Web page:<www.ragnu.it>
#Email: <vasta@ragnu.it>
#Date last Update : 06/11/2024

from vmp_json_  import Json    as Json
from vmp_json_  import JsonObj as JsonObj
from vmp_json_  import JData   as JData
from vmp_json_  import JList   as JList
from vmp_json_  import JTable  as JTable

from vmp_json_  import japi               as japi
from vmp_json_  import japi_type_list     as japi_type_list
from vmp_json_  import japi_type_table    as japi_type_table
from vmp_json_  import japi_void          as japi_void
from vmp_json_  import japi_list          as japi_list
from vmp_json_  import japi_table         as japi_table
from vmp_json_  import japi_oper          as japi_oper
from vmp_json_  import japi_oper_kill     as japi_oper_kill
from vmp_json_  import japi_oper_data     as japi_oper_data
from vmp_json_  import japi_oper_data     as japi_oper_push
from vmp_json_  import japi_oper_close    as japi_oper_close
from vmp_json_  import japi_status        as japi_status
from vmp_json_  import japi_status_update as japi_status_update
from vmp_json_  import japi_status_cancel as japi_status_cancel
from vmp_json_  import japi_login         as japi_login
from vmp_json_  import japi_login_b64_e   as japi_login_b64_e
from vmp_json_  import japi_login_b64_d   as japi_login_b64_d
